Welcome to Django Hypergen
==========================

**Take a break from hypergen**

Write server-rendered reactive HTML liveviews for Django in pure python 💫

Please read all about it here:

- `Homepage <https://hypergen.it>`_
- `Github <https://github.com/runekaagaard/django-hypergen/>`_

Thanks,

Rune Kaagaard & Jeppe Tuxen
